@@ -42,8 +42,8 @@ XScreenSaverMonitor::XScreenSaverMonitor() :
   screen_saver_info(NULL)
 {
   monitor_thread = new Thread(this);
-  mutex = g_mutex_new();
-  cond = g_cond_new();
+  g_mutex_init(&mutex);
+  g_cond_init(&cond);
 }
 
 
@@ -56,8 +56,8 @@ XScreenSaverMonitor::~XScreenSaverMonitor()
       delete monitor_thread;
     }
 
-  g_mutex_free(mutex);
-  g_cond_free(cond);
+  g_mutex_clear(&mutex);
+  g_cond_clear(&cond);
   TRACE_EXIT();
 }
 
@@ -75,7 +75,7 @@ XScreenSaverMonitor::init()
     screen_saver_info = XScreenSaverAllocInfo();
     monitor_thread->start();
   }
-  
+
   return has_extension;
 }
 
@@ -84,14 +84,14 @@ XScreenSaverMonitor::terminate()
 {
   TRACE_ENTER("XScreenSaverMonitor::terminate");
 
-  g_mutex_lock(mutex);
+  g_mutex_lock(&mutex);
   abort = true;
-  g_cond_broadcast(cond);
-  g_mutex_unlock(mutex);  
-  
+  g_cond_broadcast(&cond);
+  g_mutex_unlock(&mutex);
+
   monitor_thread->wait();
   monitor_thread = NULL;
-  
+
   TRACE_EXIT();
 }
 
@@ -101,7 +101,7 @@ XScreenSaverMonitor::run()
 {
   TRACE_ENTER("XScreenSaverMonitor::run");
 
-  g_mutex_lock(mutex);
+  g_mutex_lock(&mutex);
   while (!abort)
     {
       XScreenSaverQueryInfo(gdk_x11_display_get_xdisplay(gdk_display_get_default()), gdk_x11_get_default_root_xwindow(), screen_saver_info);
@@ -114,12 +114,12 @@ XScreenSaverMonitor::run()
 
 #if GLIB_CHECK_VERSION(2, 32, 0)
       gint64 end_time = g_get_monotonic_time() + G_TIME_SPAN_SECOND;
-      g_cond_wait_until(cond, mutex, end_time);
+      g_cond_wait_until(&cond, &mutex, end_time);
 #else
       g_usleep(500000);
-#endif      
+#endif
     }
-  g_mutex_unlock(mutex);  
-  
+  g_mutex_unlock(&mutex);
+
   TRACE_EXIT();
 }
