@@ -1,7 +1,7 @@
 /*
  * crashlog.c
  *
- * Copyright (C) 2003, 2004, 2005, 2007 Rob Caelers <robc@krandor.nl>
+ * Copyright (C) 2003, 2004, 2005, 2007, 2011 Rob Caelers <robc@krandor.nl>
  * Copyright (C) 2007 Ray Satiro <raysatiro@yahoo.com>
  * All rights reserved.
  *
@@ -56,7 +56,7 @@ static
 DWORD GetModuleBase(DWORD dwAddress)
 {
   MEMORY_BASIC_INFORMATION Buffer;
-  
+
   return VirtualQuery((LPCVOID) dwAddress, &Buffer, sizeof(Buffer)) ? (DWORD) Buffer.AllocationBase : 0;
 }
 
@@ -75,7 +75,7 @@ double_exception_handler(struct _EXCEPTION_RECORD *exception_record,
   MessageBox(NULL,
              (LPCSTR)"Workrave has unexpectedly crashed and failed to create a crash "
              "log. This is serious. Please report this to crashes@workrave.org or "
-             "file a bugreport at: http://issues.workrave.org/. " , 
+             "file a bugreport at: http://issues.workrave.org/. " ,
 			 (LPCSTR)"Double exception", MB_OK);
 
   exit(1);
@@ -136,7 +136,7 @@ exception_handler(struct _EXCEPTION_RECORD *exception_record,
       env_var[ 19 ] = '\0';
       bufsize = ( *GetEnvironmentVariableW ) ( env_var, NULL, 0 );
       // bufsize is size in wide chars, including null
-      
+
       if( !bufsize )
       // If %appdata% is unsuitable, try temp:
       {
@@ -144,10 +144,10 @@ exception_handler(struct _EXCEPTION_RECORD *exception_record,
           env_var[ 19 ] = '\0';
           bufsize = ( *GetEnvironmentVariableW ) ( env_var, NULL, 0 );
       }
-      
+
       ret = 0;
       wbuffer = NULL;
-      
+
       if( bufsize )
         {
           // We will need room for \\?\ so add 4
@@ -158,7 +158,7 @@ exception_handler(struct _EXCEPTION_RECORD *exception_record,
               ret = ( *GetEnvironmentVariableW ) ( env_var, p_wbuffer, bufsize );
             }
         }
-      
+
       if( !ret )
       // Environment unsuitable, notify & terminate.
         {
@@ -177,20 +177,20 @@ exception_handler(struct _EXCEPTION_RECORD *exception_record,
 #endif
           exit( 1 );
         }
-      
+
       //last wchar
       p_wbuffer = wbuffer + wcslen(wbuffer) - 1;
-      
+
       while( *p_wbuffer == L'\\' )
       // remove trailing slashes
         {
           *p_wbuffer-- = L'\0';
         }
-      
+
       // append filename to end of string
       wcscpy( ++p_wbuffer, crashlog );
-      
-      
+
+
       // compare first wchar of returned environment string
       if( wbuffer[ 4 ] == L'\\' )
       /*
@@ -202,8 +202,8 @@ exception_handler(struct _EXCEPTION_RECORD *exception_record,
       else
       // Point to start of wbuffer:
           p_wbuffer = wbuffer;
-      
-      
+
+
       handle = ( *CreateFileW ) (
           p_wbuffer,
           GENERIC_READ | GENERIC_WRITE,
@@ -213,7 +213,7 @@ exception_handler(struct _EXCEPTION_RECORD *exception_record,
           FILE_ATTRIBUTE_NORMAL,
           NULL
         );
-      
+
       fd = _open_osfhandle( (intptr_t) handle, _O_APPEND | _O_TEXT );
       log = _fdopen( fd, "w" );
     }
@@ -285,9 +285,6 @@ exception_handler(struct _EXCEPTION_RECORD *exception_record,
 #ifdef HAVE_GNET2
           "GNET2 "
 #endif
-#ifdef HAVE_GNOME
-          "GNOME?? "
-#endif
 #ifdef HAVE_XRECORD
           "XRECORD?? "
 #endif
@@ -299,12 +296,12 @@ exception_handler(struct _EXCEPTION_RECORD *exception_record,
 
 // write locale info:
   char *buffer = NULL;
-  int bufsize = 
+  int bufsize =
       GetLocaleInfoA( LOCALE_USER_DEFAULT, LOCALE_SENGLANGUAGE, buffer, 0);
-  
+
   if( bufsize )
       buffer = (char *)calloc( bufsize + 1, 1 );
-  
+
   if( buffer )
     {
       GetLocaleInfoA( LOCALE_USER_DEFAULT, LOCALE_SENGLANGUAGE, buffer, bufsize);
@@ -312,7 +309,7 @@ exception_handler(struct _EXCEPTION_RECORD *exception_record,
       fprintf( log, "locale = %s\n", buffer );
       free( buffer );
     }
-  
+
   fprintf(log, "\n\n");
   fprintf(log, "code = %x\n", (int) exception_record->ExceptionCode);
   fprintf(log, "flags = %x\n", (int) exception_record->ExceptionFlags);
@@ -464,18 +461,18 @@ exception_handler(struct _EXCEPTION_RECORD *exception_record,
   if( GetEnvironmentVariableW && CreateFileW )
   // >= WinNT
     {
-      WCHAR *one = 
+      WCHAR *one =
           L"Workrave has unexpectedly crashed. A crash log has been saved to:\n";
-      
-      WCHAR *two = 
+
+      WCHAR *two =
           L"\nPlease file a bug report: http://issues.workrave.org/\n"
           L"Thanks.";
-      
+
       WCHAR *nomem =
           L"Workrave is out of memory!";
-      
+
       int size = wcslen( one ) + wcslen( p_wbuffer ) + wcslen( two ) + 1;
-      
+
       WCHAR *message = (WCHAR *)calloc( size, sizeof( WCHAR ) );
       if( !message )
       // Low memory...
@@ -485,7 +482,7 @@ exception_handler(struct _EXCEPTION_RECORD *exception_record,
           message = (WCHAR *)calloc( size, sizeof( WCHAR ) );
           if( message )
             {
-              snwprintf( message, size - 1, L"%ws%%%ws%%%ws%ws", 
+              snwprintf( message, size - 1, L"%ws%%%ws%%%ws%ws",
                   one, env_var, crashlog, two );
               message[ size - 1 ] = L'\0';
             }
@@ -499,7 +496,7 @@ exception_handler(struct _EXCEPTION_RECORD *exception_record,
           snwprintf( message, size - 1, L"%ws%ws%ws", one, p_wbuffer, two );
           message[ size - 1 ] = L'\0';
         }
-      
+
       MessageBoxW( NULL, message, L"Exception", MB_OK );
     }
   else
@@ -528,7 +525,7 @@ BOOL WINAPI stack_walk(HANDLE process, LPSTACKFRAME stack_frame, PCONTEXT contex
   if (!stack_frame->Reserved[0])
     {
       stack_frame->Reserved[0] = 1;
-    
+
       stack_frame->AddrPC.Mode = AddrModeFlat;
       stack_frame->AddrPC.Offset = context_record->Eip;
       stack_frame->AddrStack.Mode = AddrModeFlat;
@@ -557,8 +554,8 @@ BOOL WINAPI stack_walk(HANDLE process, LPSTACKFRAME stack_frame, PCONTEXT contex
 
   ReadProcessMemory(process, (LPCVOID) (stack_frame->AddrFrame.Offset + 2*sizeof(DWORD)),
                     stack_frame->Params, sizeof(stack_frame->Params), NULL);
-  
-  return TRUE;  
+
+  return TRUE;
 }
 
 static void
