@@ -1,6 +1,6 @@
 // AppletWindow.cc --- Applet info Window
 //
-// Copyright (C) 2001 - 2008 Rob Caelers & Raymond Penners
+// Copyright (C) 2001 - 2008, 2011, 2012 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -23,7 +23,6 @@
 #include "config.h"
 #endif
 
-#include "nls.h"
 #include "debug.hh"
 
 #include "AppletWindow.hh"
@@ -41,7 +40,7 @@ AppletWindow::~AppletWindow()
 }
 
 void
-AppletWindow::set_timers_tooltip(std::string& tip)
+AppletWindow::set_applet_tooltip(const std::string &tip)
 {
   if (timer_box_view)
     {
@@ -49,7 +48,6 @@ AppletWindow::set_timers_tooltip(std::string& tip)
     }
 }
 
-
 void
 AppletWindow::update_applet()
 {
@@ -60,3 +58,20 @@ AppletWindow::update_applet()
     }
   TRACE_EXIT();
 }
+
+void
+AppletWindow::init_applet()
+{
+}
+
+sigc::signal<void, IAppletWindow::AppletState> &
+AppletWindow::signal_state_changed()
+{
+  return state_changed_signal;
+}
+
+sigc::signal<void> &
+AppletWindow::signal_request_activate()
+{
+  return request_activate_signal;
+}
