@@ -1,6 +1,6 @@
 // MainWindow.cc --- Main info Window
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013 Rob Caelers & Raymond Penners
+// Copyright (C) 2001 - 2013 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -255,7 +255,7 @@ MainWindow::init()
   list<Glib::RefPtr<Gdk::Pixbuf> > icons;
 
   const char *icon_files[] = {
-    "scalable/apps/workrave.svg",
+                               "scalable/apps/workrave.svg",
                                "16x16/apps/workrave.png",
                                "24x24/apps/workrave.png",
                                "32x32/apps/workrave.png",
@@ -291,9 +291,18 @@ MainWindow::init()
   timer_box_control = new TimerBoxControl("main_window", *timer_box_view);
   timer_box_view->set_geometry(ORIENTATION_LEFT, -1);
   timer_box_control->update();
-  add(*timer_box_view);
 
-  set_events(get_events() | Gdk::BUTTON_PRESS_MASK | Gdk::SUBSTRUCTURE_MASK);
+  Gtk::EventBox *eventbox = new Gtk::EventBox;
+  eventbox->set_visible_window(false);
+  eventbox->set_events(eventbox->get_events() | Gdk::BUTTON_PRESS_MASK);
+#ifndef PLATFORM_OS_OSX
+  // No popup menu on OS X
+  eventbox->signal_button_press_event().connect(sigc::mem_fun(*this,
+                                                              &MainWindow::on_timer_view_button_press_event));
+
+#endif
+  eventbox->add(*timer_box_view);
+  add(*eventbox);
 
   // Necessary for popup menu
   realize_if_needed();
@@ -457,18 +466,14 @@ MainWindow::on_delete_event(GdkEventAny *)
   return true;
 }
 
-//! Users pressed some mouse button in the main window.
 bool
-MainWindow::on_button_press_event(GdkEventButton *event)
+MainWindow::on_timer_view_button_press_event(GdkEventButton *event)
 {
-  TRACE_ENTER("MainWindow::on_button_press_event");
+  TRACE_ENTER("MainWindow::on_timer_view_button_press_event");
   bool ret = false;
 
   (void) event;
 
-#ifndef PLATFORM_OS_OSX
-  // No popup menu on OS X
-
   if ((event->type == GDK_BUTTON_PRESS) && (event->button == 3))
     {
       IGUI *gui = GUI::get_instance();
@@ -476,7 +481,6 @@ MainWindow::on_button_press_event(GdkEventButton *event)
       menus->popup(Menus::MENU_MAINWINDOW, event->button, event->time);
       ret = true;
     }
-#endif
 
   TRACE_EXIT();
   return ret;
