@@ -320,7 +320,13 @@ ExercisesPanel::on_realize()
 {
   Gtk::HBox::on_realize();
 #ifdef HAVE_GTK3
+  Glib::RefPtr<Gtk::StyleContext> style_context = get_style_context();
+
+  style_context->context_save();
+  style_context->set_state((Gtk::StateFlags)0);
+  style_context->add_class(GTK_STYLE_CLASS_BACKGROUND);
   description_text.override_background_color(get_style_context()->get_background_color());
+  style_context->context_restore();
 #else
   description_text.modify_base
     (Gtk::STATE_NORMAL, get_style()->get_background(Gtk::STATE_NORMAL));
